@@ -1,9 +1,9 @@
-import psycopg2 as _psycopg2
+import psycopg2 
 from psycopg2.extras import DictCursor as _cursor_factory
 
 from speaker import Speaker
 from commons import OKI_COL, INF_COL, ERR_COL
-from eccez import QueryError
+from eccez import QueryError, ConnectionError, BrokenConnection
 
 """
 The Mother DB engine.
@@ -54,7 +54,7 @@ class Psygres(Speaker):
             except:
                 Psygres.pg_cursor= pg_conn.cursor()
         else:
-            Psygres.pg_conn= _psycopg2.connect(Psygres._connect_str)
+            Psygres.pg_conn= psycopg2.connect(Psygres._connect_str)
             Psygres.pg_cursor= Psygres.pg_conn.cursor(
                     cursor_factory= _cursor_factory)
 
@@ -114,32 +114,57 @@ class Psygres(Speaker):
 
 
     @staticmethod
-    def _get_query(s):
+    def _get_query(s, recursion= True):
 
-        Speaker.log_info("QSQL- %s", s)
+        if recursion:
+            Speaker.log_info("QSQL- %s", s)
         cursor= Psygres.pg_cursor
 
+        cursor.execute(s)
+        res= cursor.fetchall()
+
         try:
             cursor.execute(s)
             res= cursor.fetchall()
 
+        except psycopg2.OperationalError, e:
+            if not recursion:
+                raise BrokenConnection
+
+            Speaker.log_info('Connection to DB seems broken, '
+                               'now reconnecting...')
+            try:
+                Psygres._connect()
+            except:
+                raise BrokenConnection()
+
+            # if we are inside a trans, we have to signal 
+            # the broken transaction -> exception
+            # otherwise, the query is tried once more
+            if Psygres.trans_level:
+                raise ConnectionError()
+            return Psygres._get_query(s, False)
+
         except Exception, es:
+            print Exception
             Psygres.pg_conn.rollback()
             Speaker.log_raise(
                     "Unable to execute query: %s" % 
                     ERR_COL(es), QueryError)
 
-        dict_list= []
+        # we need to conver dictRow to dict
+        lres= []
         for r in res:
-            d={}
+            d= {}
             d.update(r)
-            dict_list.append(d)
-        return dict_list
+            lres.append(d)
+        return lres
 
     @staticmethod
-    def _quiet_query(s):
+    def _quiet_query(s, recursion= True):
 
-        Speaker.log_info("QSQL- %s", s)
+        if recursion:
+            Speaker.log_info("QSQL- %s", s)
         cursor= Psygres.pg_cursor
 
         try:
@@ -150,6 +175,24 @@ class Psygres(Speaker):
                 Speaker.log_debug(
                         "Inside Trans: query not committed.")
 
+        except psycopg2.OperationalError, e:
+            if not recursion:
+                raise BrokenConnection
+
+            Speaker.log_info('Connection to DB seems broken, '
+                               'now reconnecting...')
+            try:
+                Psygres._connect()
+            except:
+                raise BrokenConnection()
+
+            # if we are inside a trans, we have to signal 
+            # the broken transaction -> exception
+            # otherwise, the query is tried once more
+            if Psygres.trans_level:
+                raise ConnectionError()
+            Psygres._quiet_query(s, False)
+
         except Exception, es:
             Psygres.pg_conn.rollback()
             Speaker.log_raise(
@@ -181,7 +224,7 @@ class Psygres(Speaker):
 
     @staticmethod
     def ov_query(s):
-        """ One Value Query: returns one only value."""
+        """ One Value Query: returns a unique value."""
         try:
             res= Psygres.or_query(s)
         except:
@@ -232,7 +275,7 @@ class PsygresFly(Speaker):
             except:
                 self.pg_cursor= pg_conn.cursor()
         else:
-            self.pg_conn= _psycopg2.connect(Psygres._connect_str)
+            self.pg_conn= psycopg2.connect(Psygres._connect_str)
             self.pg_cursor= self.pg_conn.cursor(
                     cursor_factory= _cursor_factory)
 
@@ -262,27 +305,48 @@ class PsygresFly(Speaker):
             cursor.execute(s)
             res= cursor.fetchall()
 
+        except psycopg2.OperationalError, e:
+            Speaker.log_info('Connection to DB seems broken, '
+                    'now reconnecting...') 
+            try:
+                self._connect()
+            except:
+                raise BrokenConnection()
+
+            raise ConnectionError()
+
         except Exception, es:
             Speaker.log_raise(
                     "Unable to execute query: %s" % 
                     ERR_COL(es), QueryError)
 
-        dict_list= []
+        # we need to conver dictRow to dict
+        lres= []
         for r in res:
-            d={}
+            d= {}
             d.update(r)
-            dict_list.append(d)
-        return dict_list
+            lres.append(d)
+        return lres
 
     def _quiet_query(self, s):
 
         Speaker.log_info("QSQL (%s) - %s", 
-                INF_COL(self.session_name), s)
+            INF_COL(self.session_name), s)
         cursor= self.pg_cursor
 
         try:
             cursor.execute(s)
 
+        except psycopg2.OperationalError, e:
+            Speaker.log_info('Connection to DB seems broken, '
+                    'now reconnecting...') 
+            try:
+                self._connect()
+            except:
+                raise BrokenConnection()
+
+            raise ConnectionError()
+
         except Exception, es:
             Speaker.log_raise(
                     "Unable to execute query: %s" % 
@@ -341,7 +405,7 @@ class PsygresFly(Speaker):
 
         if res<>0:
             PsygresPool.discard(self)
-            self.log_int_raise(
+            self.log_error(
                     "Session %s, unable to commit queries(): %s. "\
                     "Broken session removd from the pool.",
                     ERR_COL(self.session_name), ERR_COL(res))
@@ -648,7 +712,10 @@ class PsygresPool:
 
         PsygresPool._pool_current-= 1
         PsygresPool._del_orphan(pg_conn)
-        pg_conn._close()
+        try:
+            pg_conn._close()
+        except Exception, ss:
+            Speaker.log_error("Unable to close connection: %s", ERR_COL(ss))
 
     @staticmethod
     def discard(pg_conn):
