@@ -15,7 +15,6 @@ Where the main Mother Classes are defined:
 from commons import ERR_COL, INF_COL, OKI_COL
 from dbda import Psygres
 
-
 #
 ##
 ### Mother Symbols
@@ -67,8 +66,15 @@ def init_mother(cfile, pg_conn= None, fnaming= None):
 
     `fnaming` is a function: auto created methods will be named
     with this function. If None, a default function will be used.
-    The function has the following synopsis: foo(str) -> str
-    The input str is the name of the table.
+
+    The function has the following synopsis: 
+    
+        foo(str [,pref= None]) -> str
+
+    The input str is the name of the table. pref is a optional prefix.
+    Note that if you want to avoid method names collisions, `pref` has
+    to be used inside your function. Ie, your function must have 
+    different return values when different prefixes are used.
     """
 
     if not hasattr(DbMother, '_mo_initialized'):
@@ -76,10 +82,6 @@ def init_mother(cfile, pg_conn= None, fnaming= None):
         Speaker.log_warning("Mother already initialized.")
         return
 
-    if not fnaming:
-        from commons import MotherNaming
-        fnaming= MotherNaming
-
     d= {}
     import speaker
     import dbda
@@ -114,6 +116,22 @@ def init_mother(cfile, pg_conn= None, fnaming= None):
     _DbMap._load_map(momap)
 
     # Design Mother
+    if fnaming:
+        from speaker import Speaker, RED
+        Speaker.log_insane("Testing fnaming function...")
+        try:
+            res_str= fnaming('foo')
+            assert isinstance(res_str, str)
+        except:
+            Speaker.log_warning(
+                    "Testing %s Default fnaming function "
+                    "will be used.", RED('Failed!'))
+            fnaming= None
+    
+    if not fnaming:
+        from commons import MotherNaming
+        fnaming= MotherNaming
+
     DbMother.MotherNaming= staticmethod(fnaming)
     DbMother._mo_cfile= cfile
     DbMother._oided_mother= use_oids
@@ -149,21 +167,35 @@ def MotherSession(name= None, pg_conn= None):
     return PsygresPool.newSession(name, pg_conn) 
 
 def MotherPoolStatus():
-    """MotherPoolStatus() -> (avail, total, min, max, active)
+    """MotherPoolStatus() -> (pool_type, avail, total, min, max, active)
 
-    `avail` is the number of available connections.
-    `total` is the number of connection established.
-    Initializing Mother, `min` connections were made.
-    `max` connections are allowed on the Pool.
-    `active` is the number of used connection."""
+    pool_type: Limited, Elastic, Growing or -1 if pool is not active
+    avail: number of available connections.
+    total: number of connection established.
+    min: connections established during initialization.
+    max: maximum number of connections allowed on the Pool.
+    active: number of connections used now."""
 
     from dbda import PsygresPool
 
     if not PsygresPool._pool_initialized:
-        raise "No Pool Available: edit the Mother configuration file "\
-              "to use the Pool."
+        return ('NoPool', -1, -1, -1, -1, -1)
     return PsygresPool.status()
 
+def MotherPoolStratus():
+    """ MotherPoolStratus() -> string
+
+    This is a wrapper of MotherPoolStatus. 
+    The return value is a human readable report."""
+
+    return """
+    Pool Type               ~ %s
+    Connections Available   ~ %d
+    Connections Established ~ %d
+    Minimum Connections     ~ %d
+    Maximum Connections     ~ %d
+    Connections Employed    ~ %s 
+    """ % MotherPoolStatus()
 
 class _DbMap(Psygres):
     _map_file=       None
@@ -641,7 +673,6 @@ class DbMother(_DbMap):
         if not self.session:
             self.commit()
 
-
     def get_triggers(self, flag, when):
         """ get_triggers(flag, when) -> list(functions)
 
@@ -740,7 +771,7 @@ class DbMother(_DbMap):
         # Remember that a field is changed.
         self._moved.add(field_name)
 
-    def setFields(self,fdict,safe_mode=True):
+    def setFields(self, fdict, safe_mode= True):
         """ setFields(fdict [,safe_mode= True]) --> None
 
         Update the store with fdict. 
@@ -751,7 +782,7 @@ class DbMother(_DbMap):
         """
         # Is fdict a valid dict?
         new_fields=set(fdict.keys())
-        onzo=self._invalidFields(new_fields)
+        onzo= self._invalidFields(new_fields)
         if onzo:
             self.log_int_raise("Mth: cannot setFields(): "\
                     "invalid fields %s.", ERR_COL(str(onzo)))
@@ -772,14 +803,32 @@ class DbMother(_DbMap):
         # Remember fields changed.
         self._moved |= new_fields
 
-    def getField(self, field, value= None):
-        """ getField(field [, value= None]) --> value 
+    def getField(self, field, autoload= False):
+        """ getField(field [, autoload= False]) --> value 
 
-        Returns the value of the field `field` -if present- 
-        `value` otherwise (default None).
+        Returns the value of the field `field`, if valued.
+        If field is not valued yet, and autoload is True,
+        the value is loaded from the database automatically.
+        Otherwise, if autoload is False, CRASH!
         """
 
-        return self._store.get(field, value)
+        if field in self._store:
+            return self._store[field]
+
+        if not autoload:
+            self.log_int_raise("Mth: field %s is not valued: use autoload= True "
+                               "to load it automatically from the table |%s|.",
+                               ERR_COL(field), ERR_COL(self.table_name))
+
+        lfield= [field]
+        onzo= self._invalidFields(lfield)
+        if onzo:
+            self.log_int_raise("Mth: cannot getField(): "\
+                               "invalid field %s for table |%s|", 
+                                ERR_COL(str(field)), ERR_COL(self.table_name))
+
+        self.load(lfield)
+        return self._store[field]
 
     def getFields(self, fields= None, autoload= False):
         """ getFields([fields=None,autoload=False]) --> dict
@@ -795,7 +844,7 @@ class DbMother(_DbMap):
         if fields is None:
             return self._store.copy()
 
-        onzo=self._invalidFields(fields)
+        onzo= self._invalidFields(fields)
         if onzo:
             self.log_int_raise("Mth: cannot getFields(): "\
                     "invalid fields %s.", ERR_COL(str(onzo)))
@@ -828,6 +877,7 @@ class DbMother(_DbMap):
         # Make the query ...
         qry= self._sqlInsert(sk)
 
+        # ... and execute it
         self.oc_query(qry)
 
         # get last oid (for INSERT only)
@@ -875,11 +925,7 @@ class DbMother(_DbMap):
         qry= self._sqlUpdate(self._moved, params)
 
         # and execute it
-        try:
-            self.oc_query(qry)
-        except QueryError,ange:
-            from eccez import UpdateError
-            self.log_raise(str(ange), UpdateError)
+        self.oc_query(qry)
 
         # Debugging infos...
         self.log_insane( "Mth: fields %s moved ;)",
@@ -909,11 +955,7 @@ class DbMother(_DbMap):
         qry= self._sqlDelete(params)
 
         # and execute it
-        try:
-            self.oc_query(qry)
-        except QueryError, ange:
-            from eccez import DeleteError
-            self.log_raise(str(ange), DeleteError)
+        self.oc_query(qry)
 
         # Delete all informations...  
         self._moved.clear()
@@ -925,8 +967,10 @@ class DbMother(_DbMap):
         mf= fields and set(fields) or set(self._fieldsMissing())
 
         if not mf <= self.fields:
-            self.log_int_raise("Invalid Fields %s for table %s.",
-                    ERR_COL(list(mf - self.fields)), self.table_name)
+            from eccez import SelectError
+            self.log_raise("Invalid Fields %s for table %s.",
+                    ERR_COL(list(mf - self.fields)), 
+                    self.table_name, SelectError)
 
         if not len(mf):
             self.log_warning("No fields specified for SELECT: table %s",
@@ -948,11 +992,7 @@ class DbMother(_DbMap):
         qry= self._sqlSelect(mf, filter= filter)
 
         # and execute it
-        try:
-            res= self.or_query(qry)
-        except Exception, ange:
-            from eccez import SelectError
-            self.log_raise("Unable to SELECT: %s", str(ange), SelectError)
+        res= self.or_query(qry)
 
         # Update values on store
         self._store.update(res)
@@ -1017,7 +1057,7 @@ class DbMother(_DbMap):
         If safe_mode is False, try to load the record also if
         primary keys was not given.
         """
-        self._triggered_action(MO_LOAD,fields,safe_mode)
+        return self._triggered_action(MO_LOAD,fields,safe_mode)
 
     def insert(self):
         """ insert() --> None
@@ -1046,7 +1086,7 @@ class DbMother(_DbMap):
         This is a call to load() with safe_mode= False
         """
 
-        return  self.load(fields,safe_mode=False)
+        return self.load(fields,safe_mode=False)
 
     def refresh(self, d, flag= MO_NOA):
         """ refresh(d[,flag=MO_NOA]) --> None
@@ -1295,7 +1335,7 @@ class MotherManager:
         return self._workChild( 
                                 cbuilder,
                                 c_dict,
-                                MO_LOAD,
+                                MO_ULOAD,
                               )
                                     
 
@@ -1644,6 +1684,7 @@ class MotherManager:
             insertChild(Foo,dict)
             deleteChildren(Foo, filter)
             updateChildren(Foo, dict, filter)
+            getChild(Foo, dict)
             getChildren(builder,fields,filter,jbuilder,jfilter,outer,order)
 
 
@@ -1653,6 +1694,7 @@ class MotherManager:
             insertFoo(dict)
             deleteMultipleFoo(filter)
             updateMultipleFoo(dict, filter)
+            getFoo(dict)
             getMultipleFoo(fields, filter, jbuilder, jfilter, outer, order)
 
         * NOTE: methods already defined are not overwritten.
@@ -1668,6 +1710,11 @@ class MotherManager:
                 return self.deleteChildren(builder, filter)
             return fly_delete_children
 
+        def get_child(builder):
+            def fly_get_child(d):
+                return self.getChild(builder, d)
+            return fly_get_child
+
         def get_children(builder):
             def fly_get_children(fields= None, filter= None, 
                     jbuilder= None, jfilter= None, 
@@ -1728,6 +1775,23 @@ class MotherManager:
 
                 setattr(self, attr_name, attr)
 
+            attr_name= camel(ctbl, 'get')
+            if not hasattr(self, attr_name): 
+                
+                attr= get_child(c)
+                attr.__doc__=\
+                        " %s(dict) --> DbMother\n\n"                                    \
+                        "retrieve a unique child.\n"                                    \
+                        "Here dict acts has a filter. Note that Mother will try to\n"   \
+                        "'MO_ULOAD' the record, so dict does not have to contain\n"     \
+                        "necessarily the primary key for your record.\n"                \
+                        "Don't specify the foreign key: it's assigned automatically.\n" \
+                        "This method has the same beahaviour of DbMother.uload(): \n"   \
+                        "if a unique record is not found, an exception will be raised." \
+                        % attr_name
+
+                setattr(self, attr_name, attr)
+
             attr_name= camel(ctbl, 'updateMultiple')
             if not hasattr(self, attr_name): 
                 
@@ -1945,7 +2009,7 @@ class MotherBox(Psygres):
             filter= ''
 
         if fields is None:
-            what= "%s.*" % tbl
+            what= _J(['%s.%s' % (tbl, f) for f in self.momma.fields])
         else:
             ifields= set(fields) - self.momma.fields
             if len(ifields):
